@@ -299,6 +299,7 @@ class TemplateTestBase(object):
             handler='app.app',
             tags={'foo': 'bar'},
             timeout=120,
+            xray=None,
             memory_size=128,
             deployment_package=models.DeploymentPackage(filename='foo.zip'),
             role=models.PreCreatedIAMRole(role_arn='role:arn'),
@@ -448,6 +449,13 @@ class TestTerraformTemplate(TemplateTestBase):
         tf_resource = self.get_function(template)
         assert tf_resource['reserved_concurrent_executions'] == 5
 
+    def test_can_add_tracing_config(self, sample_app):
+        function = self.lambda_function()
+        function.xray = True
+        template = self.template_gen.generate([function])
+        tf_resource = self.get_function(template)
+        assert tf_resource['tracing_config']['mode'] == 'Active'
+
     def test_can_generate_cloudwatch_event(self):
         function = self.lambda_function()
         event = models.CloudWatchEvent(
@@ -720,6 +728,53 @@ class TestTerraformTemplate(TemplateTestBase):
                    'batch_size': 5
                }
 
+    def test_can_package_kinesis_handler(self, sample_app):
+        @sample_app.on_kinesis_record(stream='mystream', batch_size=5,
+                                      starting_position='TRIM_HORIZON')
+        def handler(event):
+            pass
+
+        config = Config.create(chalice_app=sample_app,
+                               project_dir='.',
+                               app_name='sample_app',
+                               api_gateway_stage='api')
+        template = self.generate_template(config)
+
+        assert template['resource'][
+                   'aws_lambda_event_source_mapping'][
+                   'handler-kinesis-event-source'] == {
+                   'event_source_arn': (
+                       'arn:${data.aws_partition.chalice.partition}:kinesis'
+                       ':${data.aws_region.chalice.name}:'
+                       '${data.aws_caller_identity.chalice.account_id}'
+                       ':stream/mystream'),
+                   'function_name': 'sample_app-dev-handler',
+                   'starting_position': 'TRIM_HORIZON',
+                   'batch_size': 5
+               }
+
+    def test_can_package_dynamodb_handler(self, sample_app):
+        @sample_app.on_dynamodb_record(stream_arn='arn:aws:...:stream',
+                                       batch_size=5,
+                                       starting_position='TRIM_HORIZON')
+        def handler(event):
+            pass
+
+        config = Config.create(chalice_app=sample_app,
+                               project_dir='.',
+                               app_name='sample_app',
+                               api_gateway_stage='api')
+        template = self.generate_template(config)
+
+        assert template['resource'][
+                   'aws_lambda_event_source_mapping'][
+                   'handler-dynamodb-event-source'] == {
+                       'event_source_arn': 'arn:aws:...:stream',
+                       'function_name': 'sample_app-dev-handler',
+                       'starting_position': 'TRIM_HORIZON',
+                       'batch_size': 5
+                   }
+
     def test_package_websocket_with_error_message(self, sample_websocket_app):
         config = Config.create(chalice_app=sample_websocket_app,
                                project_dir='.',
@@ -855,6 +910,7 @@ class TestSAMTemplate(TemplateTestBase):
             tags={'foo': 'bar'},
             timeout=120,
             memory_size=128,
+            xray=None,
             deployment_package=models.DeploymentPackage(filename='foo.zip'),
             role=models.ManagedIAMRole(
                 resource_name='role',
@@ -875,6 +931,7 @@ class TestSAMTemplate(TemplateTestBase):
                 'CodeUri': 'foo.zip',
                 'Handler': 'app.app',
                 'MemorySize': 128,
+                'Tracing': 'PassThrough',
                 'Role': {'Fn::GetAtt': ['Role', 'Arn']},
                 'Runtime': 'python27',
                 'Tags': {'foo': 'bar'},
@@ -939,6 +996,7 @@ class TestSAMTemplate(TemplateTestBase):
             tags={'foo': 'bar'},
             timeout=120,
             memory_size=128,
+            xray=None,
             deployment_package=models.DeploymentPackage(filename='foo.zip'),
             role=models.PreCreatedIAMRole(role_arn='role:arn'),
             security_group_ids=[],
@@ -955,6 +1013,7 @@ class TestSAMTemplate(TemplateTestBase):
                 'Handler': 'app.app',
                 'MemorySize': 128,
                 'Role': 'role:arn',
+                'Tracing': 'PassThrough',
                 'Runtime': 'python27',
                 'Tags': {'foo': 'bar'},
                 'Timeout': 120
@@ -1412,6 +1471,54 @@ class TestSAMTemplate(TemplateTestBase):
             }
         }
 
+    def test_can_package_kinesis_handler(self, sample_app):
+        @sample_app.on_kinesis_record(stream='mystream', batch_size=5)
+        def handler(event):
+            pass
+
+        config = Config.create(chalice_app=sample_app,
+                               project_dir='.',
+                               api_gateway_stage='api')
+        template = self.generate_template(config)
+        sns_handler = template['Resources']['Handler']
+        assert sns_handler['Properties']['Events'] == {
+            'HandlerKinesisEventSource': {
+                'Type': 'Kinesis',
+                'Properties': {
+                    'Stream': {
+                        'Fn::Sub': (
+                            'arn:${AWS::Partition}:kinesis:${AWS::Region}'
+                            ':${AWS::AccountId}:stream/mystream'
+                        )
+                    },
+                    'BatchSize': 5,
+                    'StartingPosition': 'LATEST',
+                },
+            }
+        }
+
+    def test_can_package_dynamodb_handler(self, sample_app):
+        @sample_app.on_dynamodb_record(stream_arn='arn:aws:...:stream',
+                                       batch_size=5)
+        def handler(event):
+            pass
+
+        config = Config.create(chalice_app=sample_app,
+                               project_dir='.',
+                               api_gateway_stage='api')
+        template = self.generate_template(config)
+        ddb_handler = template['Resources']['Handler']
+        assert ddb_handler['Properties']['Events'] == {
+            'HandlerDynamodbEventSource': {
+                'Type': 'DynamoDB',
+                'Properties': {
+                    'Stream': 'arn:aws:...:stream',
+                    'BatchSize': 5,
+                    'StartingPosition': 'LATEST',
+                },
+            }
+        }
+
     def test_can_generate_custom_domain_name(self, sample_app):
         config = Config.create(
             chalice_app=sample_app,
